@@ -16,6 +16,7 @@ This means we have to create the union of two sets:
 Copyright Mark Harfouche 2019
 """
 from datetime import datetime, timedelta
+from prettytable import PrettyTable, MARKDOWN
 import requests
 from distutils.version import LooseVersion
 
@@ -92,6 +93,7 @@ def good_nep29_minor(version_dates, n_minor=3):
                                              new_major_minor)]
     return good_versions_minor
 
+
 def nep29_versions(package_name, *,
                    n_months=24, n_minor=3,
                    skip_rc=True,
@@ -121,7 +123,7 @@ def nep29_versions(package_name, *,
 
 def main():
     import argparse
-    parser = argparse.ArgumentParser(description="NEP29 calcaulator.")
+    parser = argparse.ArgumentParser(description="NEP 29 calculator.")
     parser.add_argument('package', type=str, help='Package to deprecation')
     parser.add_argument('--n_months', type=int, default=24,
                         help='Number of months to keep supporting')
@@ -132,16 +134,19 @@ def main():
     package = args.package
     n_months = args.n_months
     n_minor = args.n_minor
-    from pprint import pprint
-    pprint(nep29_versions(package, n_months=n_months, n_minor=n_minor))
-
+    version_dates = nep29_versions(package, n_months=n_months, n_minor=n_minor)
+    t = PrettyTable(["version", "date"])
+    t.set_style(MARKDOWN)
+    for version, date in version_dates:
+        t.add_row([version, date.strftime('%Y-%m-%d')])
+    print(t)
 
 
 """
 from pprint import pprint
-print("SciPy NEP29 requirements")
+print("SciPy NEP 29 requirements")
 pprint(nep29_versions('scipy', n_months=24, n_minor=3))
 
-print("NumPy NEP29 requirements")
+print("NumPy NEP 29 requirements")
 pprint(nep29_versions('numpy', n_months=24, n_minor=3))
 """
